@@ -173,7 +173,7 @@ usage(char *progname)
                    and ratio is relative element-wise difference defined\n\
                    as |x - y|/max(|x|, |y|)\n\
   file1 file2      File names of two input netCDF files to be compared\n\
-  *PnetCDF library version 1.14.0 of November 11, 2024\n"
+  *PnetCDF library version 1.14.1 of July 31, 2025\n"
 
     printf("  %s [-b] [-q] [-h] [-v ...] [-t diff,ratio] file1 file2\n%s",
            progname, USAGE);
@@ -1035,7 +1035,7 @@ cmp_vars:
                                     break;
                             pos = ((long long)m + k * nChunks) / var[0]->xsz;
 
-                            diffStart = (long long*) malloc(var[0]->ndims * sizeof(long long));
+                            diffStart = (long long*) malloc(sizeof(long long) * var[0]->ndims);
                             for (_i=var[0]->ndims-1; _i>=0; _i--) {
                                 if (isRecVar[0] && _i == 0) {
                                     diffStart[_i] = r; /* r-th record */
@@ -1092,7 +1092,7 @@ cmp_vars:
         } else {
             int _i;
             long long pos, *diffStart;
-            diffStart = (long long*) malloc(ndims[0] * sizeof(long long));
+            diffStart = (long long*) malloc(sizeof(long long) * ndims[0]);
             if (worst != -1) pos = worst;
             for (_i=ndims[0]-1; _i>=0; _i--) {
                 long long dimLen = var[0]->shape[_i];
