@@ -72,7 +72,7 @@ int main( int argc, char *argv[] )
         printf( "PnetCDF Version:    \t%s\n", PNETCDF_VERSION);
     }
     if (flags[Date]) {
-        printf( "PnetCDF Release date:\tNovember 11, 2024\n");
+        printf( "PnetCDF Release date:\tJuly 31, 2025\n");
     }
     if (flags[Configure_args]) {
         printf( "PnetCDF configure: \t%s\n", CONFIGURE_ARGS_CLEAN);
